@@ -230,20 +230,22 @@ glamor_copy_cpu_fbo(DrawablePtr src,
             goto bail;
         }
 
+        src_pix->drawable.x = dst_xoff;
+        src_pix->drawable.y = dst_yoff;
+
         fbGetDrawable(&src_pix->drawable, src_bits, src_stride, src_bpp, src_xoff,
                       src_yoff);
 
         if (src->bitsPerPixel > 1)
-            fbCopyNto1(src, &src_pix->drawable, gc, box, nbox,
-                       dst_xoff + dx, dst_yoff + dy, reverse, upsidedown,
-                       bitplane, closure);
+            fbCopyNto1(src, &src_pix->drawable, gc, box, nbox, dx, dy,
+                       reverse, upsidedown, bitplane, closure);
         else
-            fbCopy1toN(src, &src_pix->drawable, gc, box, nbox,
-                       dst_xoff + dx, dst_yoff + dy, reverse, upsidedown,
-                       bitplane, closure);
+            fbCopy1toN(src, &src_pix->drawable, gc, box, nbox, dx, dy,
+                       reverse, upsidedown, bitplane, closure);
 
-        glamor_upload_boxes(dst_pixmap, box, nbox, 0, 0, 0, 0,
-                            (uint8_t *) src_bits, src_stride * sizeof(FbBits));
+        glamor_upload_boxes(dst_pixmap, box, nbox, src_xoff, src_yoff,
+                            dst_xoff, dst_yoff, (uint8_t *) src_bits,
+                            src_stride * sizeof(FbBits));
         fbDestroyPixmap(src_pix);
     } else {
         fbGetDrawable(src, src_bits, src_stride, src_bpp, src_xoff, src_yoff);
@@ -342,6 +344,7 @@ glamor_copy_fbo_fbo_draw(DrawablePtr src,
     glamor_program *prog;
     const glamor_facet *copy_facet;
     int n;
+    Bool ret = FALSE;
 
     glamor_make_current(glamor_priv);
 
@@ -351,6 +354,9 @@ glamor_copy_fbo_fbo_draw(DrawablePtr src,
     if (!glamor_set_alu(screen, gc ? gc->alu : GXcopy))
         goto bail_ctx;
 
+    if (bitplane && !glamor_priv->can_copyplane)
+        goto bail_ctx;
+
     if (bitplane) {
         prog = &glamor_priv->copy_plane_prog;
         copy_facet = &glamor_facet_copyplane;
@@ -405,9 +411,10 @@ glamor_copy_fbo_fbo_draw(DrawablePtr src,
             goto bail_ctx;
 
         glamor_pixmap_loop(dst_priv, dst_box_index) {
-            glamor_set_destination_drawable(dst, dst_box_index, FALSE, FALSE,
-                                            prog->matrix_uniform,
-                                            &dst_off_x, &dst_off_y);
+            if (!glamor_set_destination_drawable(dst, dst_box_index, FALSE, FALSE,
+                                                 prog->matrix_uniform,
+                                                 &dst_off_x, &dst_off_y))
+                goto bail_ctx;
 
             glScissor(dst_off_x - args.dx,
                       dst_off_y - args.dy,
@@ -417,13 +424,14 @@ glamor_copy_fbo_fbo_draw(DrawablePtr src,
             glamor_glDrawArrays_GL_QUADS(glamor_priv, nbox);
         }
     }
+
+    ret = TRUE;
+
+bail_ctx:
     glDisable(GL_SCISSOR_TEST);
     glDisableVertexAttribArray(GLAMOR_VERTEX_POS);
 
-    return TRUE;
-
-bail_ctx:
-    return FALSE;
+    return ret;
 }
 
 /**
