@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.2.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.2"
+#define YYBISON_VERSION "3.0.4"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -129,7 +129,7 @@ static void SetDefaultSysMenu (char *menu, int pos);
 static void SetTrayIcon (char *fname);
 
 static void OpenMenu(char *menuname);
-static void AddMenuLine(char *name, MENUCOMMANDTYPE cmd, char *param);
+static void AddMenuLine(const char *name, MENUCOMMANDTYPE cmd, const char *param);
 static void CloseMenu(void);
 
 static void OpenIcons(void);
@@ -144,13 +144,14 @@ static void OpenSysMenu(void);
 static void AddSysMenuLine(char *matchstr, char *menuname, int pos);
 static void CloseSysMenu(void);
 
-static int yyerror (char *s);
+static int yyerror (const char *s);
 
 extern char *yytext;
+extern int yylineno;
 extern int yylex(void);
 
 
-#line 154 "winprefsyacc.c" /* yacc.c:339  */
+#line 155 "winprefsyacc.c" /* yacc.c:339  */
 
 # ifndef YY_NULLPTR
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -249,17 +250,19 @@ extern int yydebug;
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE YYSTYPE;
+
 union YYSTYPE
 {
-#line 89 "winprefsyacc.y" /* yacc.c:355  */
+#line 90 "winprefsyacc.y" /* yacc.c:355  */
 
   char *sVal;
   unsigned long uVal;
   int iVal;
 
-#line 262 "winprefsyacc.c" /* yacc.c:355  */
+#line 263 "winprefsyacc.c" /* yacc.c:355  */
 };
+
+typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define YYSTYPE_IS_DECLARED 1
 #endif
@@ -273,7 +276,7 @@ int yyparse (void);
 
 /* Copy the second part of user declarations.  */
 
-#line 277 "winprefsyacc.c" /* yacc.c:358  */
+#line 280 "winprefsyacc.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -573,13 +576,13 @@ static const yytype_uint8 yytranslate[] =
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,   132,   132,   133,   136,   137,   141,   142,   145,   146,
-     147,   148,   149,   150,   151,   152,   153,   154,   155,   156,
-     159,   162,   165,   168,   171,   174,   175,   176,   177,   178,
-     181,   182,   185,   185,   188,   191,   192,   195,   195,   198,
-     199,   200,   201,   204,   205,   206,   209,   210,   211,   212,
-     215,   218,   219,   222,   222,   225,   226,   227,   230,   233,
-     234,   237,   237,   240,   243,   246
+       0,   133,   133,   134,   137,   138,   142,   143,   146,   147,
+     148,   149,   150,   151,   152,   153,   154,   155,   156,   157,
+     160,   163,   166,   169,   172,   175,   176,   177,   178,   179,
+     182,   183,   186,   186,   189,   192,   193,   196,   196,   199,
+     200,   201,   202,   205,   206,   207,   210,   211,   212,   213,
+     216,   219,   220,   223,   223,   226,   227,   228,   231,   234,
+     235,   238,   238,   241,   244,   247
 };
 #endif
 
@@ -1429,235 +1432,235 @@ yyreduce:
   switch (yyn)
     {
         case 20:
-#line 159 "winprefsyacc.y" /* yacc.c:1646  */
+#line 160 "winprefsyacc.y" /* yacc.c:1646  */
     { SetTrayIcon((yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
-#line 1435 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1438 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 21:
-#line 162 "winprefsyacc.y" /* yacc.c:1646  */
+#line 163 "winprefsyacc.y" /* yacc.c:1646  */
     { SetRootMenu((yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
-#line 1441 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1444 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 22:
-#line 165 "winprefsyacc.y" /* yacc.c:1646  */
+#line 166 "winprefsyacc.y" /* yacc.c:1646  */
     { SetDefaultSysMenu((yyvsp[-2].sVal), (yyvsp[-1].iVal)); free((yyvsp[-2].sVal)); }
-#line 1447 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1450 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 23:
-#line 168 "winprefsyacc.y" /* yacc.c:1646  */
+#line 169 "winprefsyacc.y" /* yacc.c:1646  */
     { SetDefaultIcon((yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
-#line 1453 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1456 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 24:
-#line 171 "winprefsyacc.y" /* yacc.c:1646  */
+#line 172 "winprefsyacc.y" /* yacc.c:1646  */
     { SetIconDirectory((yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
-#line 1459 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1462 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 25:
-#line 174 "winprefsyacc.y" /* yacc.c:1646  */
+#line 175 "winprefsyacc.y" /* yacc.c:1646  */
     { AddMenuLine("-", CMD_SEPARATOR, ""); }
-#line 1465 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1468 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 26:
-#line 175 "winprefsyacc.y" /* yacc.c:1646  */
+#line 176 "winprefsyacc.y" /* yacc.c:1646  */
     { AddMenuLine((yyvsp[-3].sVal), CMD_ALWAYSONTOP, ""); free((yyvsp[-3].sVal)); }
-#line 1471 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1474 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 27:
-#line 176 "winprefsyacc.y" /* yacc.c:1646  */
+#line 177 "winprefsyacc.y" /* yacc.c:1646  */
     { AddMenuLine((yyvsp[-4].sVal), CMD_EXEC, (yyvsp[-2].sVal)); free((yyvsp[-4].sVal)); free((yyvsp[-2].sVal)); }
-#line 1477 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1480 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 28:
-#line 177 "winprefsyacc.y" /* yacc.c:1646  */
+#line 178 "winprefsyacc.y" /* yacc.c:1646  */
     { AddMenuLine((yyvsp[-4].sVal), CMD_MENU, (yyvsp[-2].sVal)); free((yyvsp[-4].sVal)); free((yyvsp[-2].sVal)); }
-#line 1483 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1486 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 29:
-#line 178 "winprefsyacc.y" /* yacc.c:1646  */
+#line 179 "winprefsyacc.y" /* yacc.c:1646  */
     { AddMenuLine((yyvsp[-3].sVal), CMD_RELOAD, ""); free((yyvsp[-3].sVal)); }
-#line 1489 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1492 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 32:
-#line 185 "winprefsyacc.y" /* yacc.c:1646  */
+#line 186 "winprefsyacc.y" /* yacc.c:1646  */
     { OpenMenu((yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
-#line 1495 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1498 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 33:
-#line 185 "winprefsyacc.y" /* yacc.c:1646  */
+#line 186 "winprefsyacc.y" /* yacc.c:1646  */
     {CloseMenu();}
-#line 1501 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1504 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 34:
-#line 188 "winprefsyacc.y" /* yacc.c:1646  */
+#line 189 "winprefsyacc.y" /* yacc.c:1646  */
     { AddIconLine((yyvsp[-3].sVal), (yyvsp[-2].sVal)); free((yyvsp[-3].sVal)); free((yyvsp[-2].sVal)); }
-#line 1507 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1510 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 37:
-#line 195 "winprefsyacc.y" /* yacc.c:1646  */
+#line 196 "winprefsyacc.y" /* yacc.c:1646  */
     {OpenIcons();}
-#line 1513 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1516 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 38:
-#line 195 "winprefsyacc.y" /* yacc.c:1646  */
+#line 196 "winprefsyacc.y" /* yacc.c:1646  */
     {CloseIcons();}
-#line 1519 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1522 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 39:
-#line 198 "winprefsyacc.y" /* yacc.c:1646  */
+#line 199 "winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=STYLE_TOPMOST; }
-#line 1525 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1528 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 40:
-#line 199 "winprefsyacc.y" /* yacc.c:1646  */
+#line 200 "winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=STYLE_MAXIMIZE; }
-#line 1531 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1534 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 41:
-#line 200 "winprefsyacc.y" /* yacc.c:1646  */
+#line 201 "winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=STYLE_MINIMIZE; }
-#line 1537 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1540 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 42:
-#line 201 "winprefsyacc.y" /* yacc.c:1646  */
+#line 202 "winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=STYLE_BOTTOM; }
-#line 1543 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1546 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 43:
-#line 204 "winprefsyacc.y" /* yacc.c:1646  */
+#line 205 "winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=STYLE_NOTITLE; }
-#line 1549 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1552 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 44:
-#line 205 "winprefsyacc.y" /* yacc.c:1646  */
+#line 206 "winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=STYLE_OUTLINE; }
-#line 1555 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1558 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 45:
-#line 206 "winprefsyacc.y" /* yacc.c:1646  */
+#line 207 "winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=STYLE_NOFRAME; }
-#line 1561 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1564 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 46:
-#line 209 "winprefsyacc.y" /* yacc.c:1646  */
+#line 210 "winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=(yyvsp[0].uVal); }
-#line 1567 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1570 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 47:
-#line 210 "winprefsyacc.y" /* yacc.c:1646  */
+#line 211 "winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=(yyvsp[0].uVal); }
-#line 1573 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1576 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 48:
-#line 211 "winprefsyacc.y" /* yacc.c:1646  */
+#line 212 "winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
-#line 1579 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1582 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 49:
-#line 212 "winprefsyacc.y" /* yacc.c:1646  */
+#line 213 "winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
-#line 1585 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1588 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 50:
-#line 215 "winprefsyacc.y" /* yacc.c:1646  */
+#line 216 "winprefsyacc.y" /* yacc.c:1646  */
     { AddStyleLine((yyvsp[-3].sVal), (yyvsp[-2].uVal)); free((yyvsp[-3].sVal)); }
-#line 1591 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1594 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 53:
-#line 222 "winprefsyacc.y" /* yacc.c:1646  */
+#line 223 "winprefsyacc.y" /* yacc.c:1646  */
     {OpenStyles();}
-#line 1597 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1600 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 54:
-#line 222 "winprefsyacc.y" /* yacc.c:1646  */
+#line 223 "winprefsyacc.y" /* yacc.c:1646  */
     {CloseStyles();}
-#line 1603 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1606 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 55:
-#line 225 "winprefsyacc.y" /* yacc.c:1646  */
+#line 226 "winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.iVal)=AT_END; }
-#line 1609 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1612 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 56:
-#line 226 "winprefsyacc.y" /* yacc.c:1646  */
+#line 227 "winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.iVal)=AT_START; }
-#line 1615 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1618 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 57:
-#line 227 "winprefsyacc.y" /* yacc.c:1646  */
+#line 228 "winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.iVal)=AT_END; }
-#line 1621 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1624 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 58:
-#line 230 "winprefsyacc.y" /* yacc.c:1646  */
+#line 231 "winprefsyacc.y" /* yacc.c:1646  */
     { AddSysMenuLine((yyvsp[-4].sVal), (yyvsp[-3].sVal), (yyvsp[-2].iVal)); free((yyvsp[-4].sVal)); free((yyvsp[-3].sVal)); }
-#line 1627 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1630 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 61:
-#line 237 "winprefsyacc.y" /* yacc.c:1646  */
+#line 238 "winprefsyacc.y" /* yacc.c:1646  */
     {OpenSysMenu();}
-#line 1633 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1636 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 62:
-#line 237 "winprefsyacc.y" /* yacc.c:1646  */
+#line 238 "winprefsyacc.y" /* yacc.c:1646  */
     {CloseSysMenu();}
-#line 1639 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1642 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 63:
-#line 240 "winprefsyacc.y" /* yacc.c:1646  */
+#line 241 "winprefsyacc.y" /* yacc.c:1646  */
     { pref.fForceExit = TRUE; }
-#line 1645 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1648 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 64:
-#line 243 "winprefsyacc.y" /* yacc.c:1646  */
+#line 244 "winprefsyacc.y" /* yacc.c:1646  */
     { pref.fSilentExit = TRUE; }
-#line 1651 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1654 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 65:
-#line 246 "winprefsyacc.y" /* yacc.c:1646  */
+#line 247 "winprefsyacc.y" /* yacc.c:1646  */
     { ErrorF("LoadPreferences: %s\n", (yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
-#line 1657 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1660 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
 
-#line 1661 "winprefsyacc.c" /* yacc.c:1646  */
+#line 1664 "winprefsyacc.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1885,16 +1888,14 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 250 "winprefsyacc.y" /* yacc.c:1906  */
+#line 251 "winprefsyacc.y" /* yacc.c:1906  */
 
 /*
  * Errors in parsing abort and print log messages
  */
 static int
-yyerror (char *s) 
+yyerror (const char *s)
 {
-  extern int yylineno; /* Handled by flex internally */
-
   ErrorF("LoadPreferences: %s line %d\n", s, yylineno);
   return 1;
 }
@@ -1947,7 +1948,7 @@ OpenMenu (char *menuname)
 }
 
 static void
-AddMenuLine (char *text, MENUCOMMANDTYPE cmd, char *param)
+AddMenuLine (const char *text, MENUCOMMANDTYPE cmd, const char *param)
 {
   if (menu.menuItem==NULL)
     menu.menuItem = malloc(sizeof(MENUITEM));
